@@ -1127,10 +1127,14 @@ static HTMLURL *baseURL;
 static void
 on_set_base (GtkHTML *html, const gchar *url, gpointer data)
 {
+	HTMLURL *tmpurl;
+	
 	if (baseURL)
 		html_url_destroy (baseURL);
-	g_message ("new base: %s", url);
-	baseURL = html_url_new (url);
+
+	tmpurl = html_url_new (url);
+	baseURL = html_url_dup (tmpurl, HTML_URL_DUP_NOREFERENCE);
+	html_url_destroy (tmpurl);
 }
 
 static gchar *
@@ -1231,7 +1235,7 @@ url_requested (GtkHTML *html, const char *url, GtkHTMLStreamHandle handle, HelpW
 
 	if (transport(obj, helpWindowGetCache(win))) {
 	    docObjFree(obj);
-	    gtk_html_stream_end (html, handle, GTK_HTML_STREAM_ERROR);
+	    gtk_html_end (html, handle, GTK_HTML_STREAM_ERROR);
 	    return;
 	}
 
