@@ -1,3 +1,13 @@
+/*
+ * GNOME panel utils
+ * (C) 1997, 1998, 1999, 2000 The Free Software Foundation
+ * Copyright 2000 Helix Code, Inc.
+ * Copyright 2000 Eazel, Inc.
+ *
+ * Authors: George Lebl
+ *          Jacob Berkman
+ */
+
 #include <config.h>
 #include <string.h>
 #include <glib.h>
@@ -7,6 +17,16 @@
 
 #include "panel-include.h"
 
+extern GlobalConfig global_config;
+
+void
+panel_pbox_help_cb (GtkWidget *w, gint tab, gpointer path)
+{
+	GnomeHelpMenuEntry help_entry = { "panel" };
+	help_entry.path = path;
+	gnome_help_display(NULL, &help_entry);
+}
+
 gboolean
 string_is_in_list(GSList *list,char *text)
 {
@@ -601,6 +621,8 @@ convert_string_to_keysym_state(char *string,
 
 	s = g_strdup(string);
 
+	gdk_error_trap_push();
+
 	p = strtok(s, "-");
 	while(p) {
 		if(strcmp(p, "Control")==0) {
@@ -620,10 +642,10 @@ convert_string_to_keysym_state(char *string,
 		} else if(strcmp(p, "Mod5")==0) {
 			*state |= GDK_MOD5_MASK;
 		} else {
-			gdk_error_trap_push();
 			*keysym = gdk_keyval_from_name(p);
-			gdk_error_trap_pop();
 			if(*keysym == 0) {
+				gdk_flush();
+				gdk_error_trap_pop();
 				g_free(s);
 				return FALSE;
 			}
@@ -631,6 +653,9 @@ convert_string_to_keysym_state(char *string,
 		p = strtok(NULL, "-");
 	}
 
+	gdk_flush();
+	gdk_error_trap_pop();
+
 	g_free(s);
 
 	if(*keysym == 0)
@@ -652,6 +677,7 @@ convert_keysym_state_to_string(guint keysym,
 
 	gdk_error_trap_push();
 	key = gdk_keyval_name(keysym);
+	gdk_flush();
 	gdk_error_trap_pop();
 	if(!key) return NULL;
 
@@ -707,3 +733,44 @@ convert_keysym_state_to_string(guint keysym,
 		return ret;
 	}
 }
+
+static void
+panel_dialog_realized(GtkWidget *dialog)
+{
+	if(!global_config.keep_bottom)
+		gnome_win_hints_set_layer (GTK_WIDGET(dialog),
+					   WIN_LAYER_ABOVE_DOCK);
+}
+
+void
+panel_set_dialog_layer(GtkWidget *dialog)
+{
+	if(GTK_WIDGET_REALIZED(dialog) &&
+	   !global_config.keep_bottom)
+		gnome_win_hints_set_layer (GTK_WIDGET(dialog),
+					   WIN_LAYER_ABOVE_DOCK);
+
+	gtk_signal_connect(GTK_OBJECT(dialog), "realize",
+			   GTK_SIGNAL_FUNC(panel_dialog_realized),
+			   NULL);
+}
+
+GtkWidget *
+panel_error_dialog(char *format, ...)
+{
+	GtkWidget *w;
+	char *s;
+	va_list ap;
+
+	va_start(ap, format);
+	s = g_strdup_vprintf(format, ap);
+	va_end(ap);
+
+	w = gnome_error_dialog(s);
+	g_free(s);
+
+	panel_set_dialog_layer(w);
+
+	return w;
+}
+
